# gtbook
> An <a href='https://nbdev.fast.ai/'>nbdev</a> powered toolbox for Frank and Seth's robotics book.


## Notes while installing

- *Needs* `pip3 install -U nbdev`, not conda (has old version)
- just do 'make' after changing any notebook.

## Install

`pip install gtbook`

## How to use

Fill me in please! Don't forget code examples:

```python
1+1
```




    2


